@@ -132,7 +132,7 @@ KComboBoxTest::KComboBoxTest(QWidget *widget)
 
     // Setup konq's combobox
     KConfig historyConfig(QStringLiteral("konq_history"), KConfig::SimpleConfig);
-    KConfigGroup cg(&historyConfig, "Location Bar");
+    KConfigGroup cg(&historyConfig, QStringLiteral("Location Bar"));
     KCompletion *s_pCompletion = new KCompletion;
     s_pCompletion->setOrder(KCompletion::Weighted);
     s_pCompletion->setItems(cg.readEntry("ComboContents", QStringList()));
@@ -218,13 +218,6 @@ void KComboBoxTest::slotTextActivated(const QString &item)
     qDebug() << "Activated Combo:" << qPrintable(sender()->objectName()) << ", item:" << item;
 }
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
-void KComboBoxTest::slotReturnPressed()
-{
-    qDebug() << "Return Pressed:" << qPrintable(sender()->objectName());
-}
-#endif
-
 void KComboBoxTest::slotReturnPressed(const QString &item)
 {
     qDebug() << "Return Pressed:" << qPrintable(sender()->objectName()) << ", value =" << item;
